
# proces name
PROCESS_NAME=inetd

# inet server config
CONFIG_FILE=/etc/inetd.conf
CONFIG_FILE_UMASK=027

# inet server daemon executable file name
INETDAEMON=/usr/sbin/inetd

# additional inet server daemon argumments
INETDAEMON_ARGS=

PREAMBLE="# This file is autogenerated from /etc/sysconfig/rc-inetd!"

parse_one_service()
{
	ERROR_CODE=0

	[ ${SERVICE_NAME:-not} = "not" ]	&& ERROR_CODE=11
	[ ${PROTOCOL:-not} = "not" ]		&& ERROR_CODE=12
	[ ${USER:-not} = "not" ]		&& ERROR_CODE=14
	[ ${SERVER:-not} = "not" ]		&& ERROR_CODE=15
	[ ${FLAGS:-not} = "not" ]		&& ERROR_CODE=16
	[ ${DAEMON:-not} = "not" ]		&& ERROR_CODE=17
	if [ ${RPCNAME:-not} = "not" ]; then
		[ ${PORT:-not} = "not" ]		&& ERROR_CODE=13
	else
		[ ${RPCVERSION:-not} = "not" ]		&& ERROR_CODE=18
	fi

	if [ ! $ERROR_CODE -eq 0 ] ; then
		echo "ERROR: Parse error."
		case "$ERROR_CODE" in
			11)
				echo "SERVICE_NAME not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			12)
				echo "PROTOCOL not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			13)
				echo "PORT not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			14)
				echo "USER not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			15)
				echo "SERVER not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			16)
				echo "FLAGS not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			17)
				echo "DAEMON not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			18)
				echo "RPCVERSION not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
		esac
		return $ERROR_CODE
	fi

	_WAIT=
	for i in $FLAGS; do
		case "$i" in
		wait|nowait)
			if [ "${MAX_CONNECTIONS:-none}" != "none" ]; then
				_WAIT="$i.$MAX_CONNECTIONS"
			else
				_WAIT="$i"
			fi
			;;
		*)
			;;
		esac
	done
	[ "$SERVER" = "tcpd" ] && SERVER="/usr/sbin/tcpd"
	[ "${GROUP:-none}" = "none" ] || USER="$USER.$GROUP"
	# if we have service on some unusual port, or have some service with strange name
	# how to grep tab???   quoting it ?
	# don't forget of service aliases
	grep -qs "^${SERVICE_NAME}[ \	]*${PORT}/$PROTOCOL" /etc/services \
	|| grep -qs "[^#]*${PORT}/$PROTOCOL[^#]*[ \	]*${SERVICE_NAME}[ \	]" /etc/services \
	|| SERVICE_NAME=${PORT}

	if [ ${RPCNAME:-not} = "not" ]; then
		echo "$SERVICE_NAME	$SOCK_TYPE	$PROTOCOL	$_WAIT	$USER	$SERVER $DAEMON $DAEMONARGS"
	else
		echo "$RPCNAME/$RPCVERSION	$SOCK_TYPE	rpc/$PROTOCOL	$_WAIT	$USER	$SERVER $DAEMON $DAEMONARGS"
	fi

	return 0
}

status_rc_inetd()
{
	status $INETDAEMON
}
reload_config()
{
	killproc $INETDAEMON -HUP
}
